@@ -9,6 +9,9 @@
 #   include <QtOpenGL>
 #endif
 
+#define QT_USE_FAST_CONCATENATION
+#define QT_USE_FAST_OPERATOR_PLUS
+
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
